@@ -204,7 +204,8 @@ install_environment <- function(
     envname <- use_envname(
       backend = backend,
       version = ver_name,
-      ask_if_not_installed = FALSE
+      ask_if_not_installed = FALSE,
+      python_version = python_version
     )
   }
   cli_alert_success(
@@ -217,7 +218,8 @@ install_environment <- function(
     "PyArrow",
     "grpcio",
     "google-api-python-client",
-    "grpcio_status"
+    "grpcio_status",
+    "databricks-sdk"
   )
 
   if (add_torch && install_ml) {
@@ -275,7 +277,7 @@ install_environment <- function(
     method = method,
     python_version = python_version,
     pip = TRUE,
-    ... = ...
+    ...
   )
 }
 
@@ -326,7 +328,7 @@ python_library_info <- function(
     cli_progress_step(
       "{.header Retrieving version from PyPi.org}",
       msg_done = paste0(
-        "{.header Using:} {.emph '{ret$name}'} {.header version} {ret$version},",
+        "{.header PyPi specs:} {.emph '{ret$name}'} {.header version} {ret$version},",
         " {.header requires Python }{ret$requires_python}"
       ),
       msg_failed = "{.header {msg_fail}}"
